@@ -22,10 +22,11 @@
 #include <iostream>
 
 // these are for locating the stroke information file
-#include <kstandarddirs.h>
+
 
 
 // #include <string>
+#include <QStandardPaths>
 
 using namespace std;
 
@@ -187,7 +188,7 @@ void MTStroke::getExtent()
 bool MTStroke::readSequence()
 {
   QString strokefilename;
-  strokefilename = KStandardDirs::locate("config", QLatin1String( "kmousetool_strokes.txt" ) );
+  strokefilename = QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral( "kmousetool_strokes.txt" ) );
   if (strokefilename.isEmpty()) {
     // make default
     if (sequenceMap.size()==0)
@@ -195,7 +196,7 @@ bool MTStroke::readSequence()
     writeSequence();
     return false;
   }
-  ifstream infile (strokefilename.toAscii().constData());
+  ifstream infile (strokefilename.toLatin1().constData());
   if (!infile) {
     // make default
     if (sequenceMap.size()==0)
@@ -223,9 +224,9 @@ bool MTStroke::readSequence()
 bool MTStroke::writeSequence()
 {
   QString strokefilename;
-  strokefilename = KStandardDirs::locateLocal("config", QLatin1String( "kmousetool_strokes.txt" ));
+  strokefilename = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1String("/kmousetool_strokes.txt" );
 
-  ofstream outfile (strokefilename.toAscii(), ios::out);
+  ofstream outfile (strokefilename.toLatin1(), ios::out);
   if (!outfile) {
     return false;
   }
